@@ -18,8 +18,15 @@ from openid.extensions import sreg, ax, pape
 
 from oauth2 import Consumer as OAuthConsumer, Token, Request as OAuthRequest
 
+try:
+    import json as simplejson
+except ImportError:
+    try:
+        import simplejson
+    except ImportError:
+        from django.utils import simplejson
+
 from django.contrib.auth import authenticate
-from django.utils import simplejson
 from django.utils.importlib import import_module
 
 from social_auth.models import UserSocialAuth
